@@ -546,8 +546,12 @@ fn calc_alignment_vectors(
 }
 
 fn cigar_has_softclips(rec: &bam::Record) -> bool {
-    let cigar = rec.cigar_cached().unwrap();
-    cigar.leading_softclips() > 0 || cigar.trailing_softclips() > 0
+    for cigar_operation in rec.cigar_cached().unwrap().iter() {
+        if let bam::record::Cigar::SoftClip(_) = cigar_operation {
+            return true;
+        }
+    }
+    false
 }
 
 fn match_single_cigar(cigar: &Option<char>, first_vec: &mut Vec<bool>, second_vec: &mut Vec<bool>) {
